@@ -2,24 +2,81 @@ package Clustericious;
 
 use strict;
 use warnings;
+use 5.010;
+use File::Spec;
+use File::HomeDir;
 
 # ABSTRACT: A framework for RESTful processing systems.
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
+sub _testing
+{
+  state $test = 0;
+  my($class, $new) = @_;
+  $test = $new if defined $new;
+  $test;
+}
+
+sub _config_path
+{
+  grep { -d $_ }
+    map { File::Spec->catdir(@$_) } 
+    grep { defined $_->[0] }
+    (
+      [ $ENV{CLUSTERICIOUS_CONF_DIR} ],
+      (!_testing) ? (
+        [ File::HomeDir->my_home, 'etc' ],
+        [ File::HomeDir->my_dist_config('Clustericious') ],
+        [ '', 'etc' ],
+      ) : (),
+    );
+}
+
+sub _slurp_pid ($)
+{
+  use autodie;
+  my($fn) = @_;
+  open my $fh, '<', $fn;
+  my $pid = <$fh>;
+  close $fh;
+  chomp $pid;
+  $pid;
+}
+
+sub _dist_dir
+{
+  require Path::Class::File;
+  require Path::Class::Dir;
+  $_ = __FILE__; s{(Clustericious).pm}{.$1.devshare}; -e $_
+    ? Path::Class::File->new(__FILE__)->parent->parent->subdir('share')
+    : do {
+      require File::ShareDir;
+      Path::Class::Dir->new(
+        File::ShareDir::dist_dir('Clustericious'),
+      );
+    }
+}
+
+# Note sub _config_uncache also gets placed
+# in this package, but it is defined in
+# Clustericious::Config.
+
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious - A framework for RESTful processing systems.
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
@@ -27,10 +84,6 @@ Generate a new Clustericious application:
 
  % clustericious generate app MyApp
 
-Generate a new Clustericious application database schema:
-
- % clustericious generate mbd_app MyApp --schema schema.sql
-
 Basic application layout:
 
  package MyApp;
@@ -134,52 +187,13 @@ facilities for a variety of deployment options.
 
 =back
 
-=head1 TODO
-
-I am ramping up to a release candidate and a final release for 1.00.
-Specific things that need to be completed for this task include
-(but are not limited to):
-
-=over 4
-
-=item *
-
-documentation tutorial for a non database app
-
-=item *
-
-documentation tutorial for a L<Module::Build::Database> / L<Rose::Planter> app 
-(replacement for the existing README, which is broken)
-
-=item *
-
-use SQLite for above instead of Postgres
-
-=item *
-
-documentation tutorial for migrating SQLite app to Postgres
-
-=item *
-
-documentation tutorial for clients (L<Clustericious::Client>)
-
-=item *
-
-remove C<TEST_HARNESS> detection / dependency (see GH#8)
-
-=back
-
-=head1 NOTES
-
-This is a beta release.  The API is subject to change without notice.
-
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -191,4 +205,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
