@@ -1,4 +1,3 @@
-
 package Clustericious::App;
 
 use strict;
@@ -13,20 +12,19 @@ use Mojo::ByteStream qw/b/;
 use Data::Dumper;
 use Clustericious::Log;
 use Mojo::URL;
-use JSON::XS;
 use Scalar::Util qw/weaken/;
 use Mojo::Base 'Mojolicious';
 use File::HomeDir ();
 use Carp qw( cluck );
+use Clustericious;
 use Clustericious::Controller;
 use Clustericious::Renderer;
-use Clustericious::RouteBuilder;
 use Clustericious::RouteBuilder::Common;
 use Clustericious::Config;
 use Clustericious::Commands;
 
 # ABSTRACT: Clustericious app base class
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 sub _have_rose {
@@ -59,9 +57,23 @@ sub Math::BigInt::TO_JSON {
 }
 
 
+my @route_builders;
+
+sub _add_route_builder
+{
+  push @route_builders, $_[1];
+}
+
 sub startup {
     my $self = shift;
 
+    @{ $self->static->paths } = (
+      Clustericious
+        ->_dist_dir
+        ->subdir(qw( www 1.08 ))
+        ->stringify
+    );
+
     $self->controller_class('Clustericious::Controller');
     $self->renderer(Clustericious::Renderer->new());
     $self->renderer->classes([qw/Clustericious::Templates/]);
@@ -79,12 +91,7 @@ sub startup {
     }
 
     $self->plugins->namespaces(['Mojolicious::Plugin','Clustericious::Plugin']);
-    my $config = eval { Clustericious::Config->new(ref $self) };
-    if(my $error = $@)
-    {
-        $self->log->error("error loading config $error");
-        $config = Clustericious::Config->new({ clustericious_config_error => $error });
-    }
+    my $config = $self->config;
     my $auth_plugin;
     if(my $auth_config = $config->plug_auth(default => '')) {
         $self->log->info("Loading auth plugin plug_auth");
@@ -102,7 +109,7 @@ sub startup {
     my $r = $self->routes;
     # "Common" ones are not overrideable.
     Clustericious::RouteBuilder::Common->_add_routes($self);
-    Clustericious::RouteBuilder->_add_routes($self, $auth_plugin);
+    $_->($self, $auth_plugin) for @route_builders;
 
     $self->plugin('AutodataHandler');
     $self->plugin('DefaultHelpers');
@@ -118,7 +125,6 @@ sub startup {
         $self->log->warn("Configuration file should contain 'url'.");
     };
 
-    $self->helper( _clustericious_config => sub { $config } );
     $self->helper( url_with => sub {
         my $c = shift;
         my $q = $c->req->url->clone->query;
@@ -250,13 +256,41 @@ sub dump_api_table
 
 
 sub config {
-    my $app = shift;
-    if (my $what = shift) {
-        # Mojo config interface
-        $app->_clustericious_config(@_)->{$what};
-    } else {
-        $app->_clustericious_config(@_);
+  my($self, $what) = @_;
+
+  unless($self->{_config})
+  {
+    my $config = $self->{_config} = eval { Clustericious::Config->new(ref $self) };
+    if(my $error = $@)
+    {
+      $self->log->error("error loading config $error");
+      $config = $self->{_config} = Clustericious::Config->new({ clustericious_config_error => $error });
     }
+
+    if($config->{url})
+    {
+      if(grep { $_ eq 'hypnotoad' } $config->start_mode(default => [ 'hypnotoad' ]) )
+      {
+        my $hypnotoad = $config->hypnotoad(
+          default => sub {
+            my $url = Mojo::URL->new($config->{url});
+            {
+              pid_file => File::Spec->catfile( File::HomeDir->my_dist_data("Clustericious", { create => 1 } ), 'hypnotoad-' . $url->port . '-' . $url->host . '.pid' ),
+              listen => [
+                $url->to_string,
+              ],
+            };
+          }
+        );
+      }
+    }
+  }
+
+  my $config = $self->{_config};
+
+  # Mojo uses $app->config('what');
+  # Clustericious usually uses $app->config->what;
+  $what ? $config->{$what} : $config;
 }
 
 
@@ -276,17 +310,19 @@ sub sanity_check
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::App - Clustericious app base class
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
@@ -353,11 +389,11 @@ L<Clustericious>
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -369,4 +405,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
