@@ -2,17 +2,11 @@ package Clustericious::Client;
 
 use strict;
 use warnings;
-
-# ABSTRACT: Construct command line and perl clients for RESTful services.
-our $VERSION = '1.00'; # VERSION
-
-
+use 5.010;
 use Mojo::Base qw/-base/;
-
 use Mojo::UserAgent;
 use Mojo::ByteStream qw/b/;
 use Mojo::Parameters;
-use JSON::XS;
 use Clustericious::Config;
 use Clustericious::Client::Object;
 use Clustericious::Client::Meta;
@@ -20,6 +14,10 @@ use Clustericious::Client::Meta::Route;
 use MojoX::Log::Log4perl;
 use Log::Log4perl qw/:easy/;
 use File::Temp;
+use JSON::MaybeXS qw( encode_json decode_json );
+
+# ABSTRACT: Construct command line and perl clients for RESTful services.
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 has server_url => '';
@@ -47,6 +45,14 @@ sub import
 }
 
 
+sub _mojo_user_agent_factory
+{
+  my($class, $new) = @_;
+  state $factory = sub { Mojo::UserAgent->new };
+  $factory = $new if $new;
+  defined wantarray ? $factory->() : ();
+}
+
 sub new
 {
     my $self = shift->SUPER::new(@_);
@@ -56,7 +62,7 @@ sub new
     {
         my $app = $self->{app};
         $app = $app->new() unless ref($app);
-        my $client = Mojo::UserAgent->new;
+        my $client = $self->_mojo_user_agent_factory();
         return undef unless $client;
         eval { $client->server->app($app) } // $client->app($app);
 
@@ -64,7 +70,7 @@ sub new
     }
     else
     {
-        $self->client(Mojo::UserAgent->new);
+        $self->client($self->_mojo_user_agent_factory());
         if (not length $self->server_url)
         {
             my $url = $self->_config->url;
@@ -73,7 +79,14 @@ sub new
         }
     }
 
-    $self->client->inactivity_timeout($ENV{CLUSTERICIOUS_KEEP_ALIVE_TIMEOUT} || 300);
+    my $client = $self->client;
+    $client->transactor->name($self->user_agent_string);
+    $client->inactivity_timeout($ENV{CLUSTERICIOUS_KEEP_ALIVE_TIMEOUT} || 300);
+
+    if(eval { require Clustericious::Client::Local; })
+    {
+        Clustericious::Client::Local->local($self);
+    }
 
     return $self;
 }
@@ -131,7 +144,7 @@ sub errorstring {
     }
     else
     {
-        return $error->{message};
+        return $error->{message} // '';
     }
 }
 
@@ -145,6 +158,17 @@ sub has_error {
 }
 
 
+sub user_agent_string {
+    my($self) = @_;
+    my $class = ref($self);
+    my $version1 = $Clustericious::Client::VERSION // 'dev';
+    my $version2 = do {
+      no strict 'refs';
+      ${"${class}::VERSION"};
+    } // 'dev';
+    "Clustericious::Client/$version1 $class/$version2";
+}
+
 
 sub route {
     my $subname = shift;
@@ -490,7 +514,12 @@ sub _base_config {
     # Independent of remotes
     my $self = shift;
     return $self->{_base_config} if defined($self->{_base_config});
-    $self->{_base_config} = Clustericious::Config->new($self->_appname);
+    
+    my $config_name = ref $self;
+    $config_name =~ s/::Client$//;
+    $config_name =~ s/::/-/;
+    
+    $self->{_base_config} = Clustericious::Config->new($config_name);
     return $self->{_base_config};
 }
 
@@ -568,15 +597,18 @@ sub logtail {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::Client - Construct command line and perl clients for RESTful services.
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
@@ -644,8 +676,6 @@ From the command line :
 
 =head1 DESCRIPTION
 
-This is a beta release.  The API is subject to changes without notice.
-
 Clustericious::Client is library for construction clients for RESTful
 services.  It provides a mapping between command line arguments, method
 arguments, and URLs.
@@ -740,6 +770,13 @@ parts)
 
 Returns true if there was a recent error.
 
+=head2 user_agent_string
+
+Returns the user agent string for use in HTTP transactions.
+By default this includes the clustericious and service
+version numbers, but you can override it to be whatever
+you want.
+
 =head1 FUNCTIONS
 
 =head2 route
@@ -1030,11 +1067,11 @@ L<Clustericious::Config>, L<Clustericious>, L<Mojolicious>
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -1046,4 +1083,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
