@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Command line type processing for clients.
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 use File::Basename qw/basename/;
@@ -96,7 +96,6 @@ sub run {
     my $class = shift;
     my $client = shift;
     my @args = @_ ? @_ : @ARGV;
-    our $TESTING;
 
     return $class->_usage($client) if !$args[0] || $args[0] =~ /help/;
 
@@ -164,7 +163,7 @@ sub run {
             }
             INFO $msg;
         } else {
-           print _prettyDump($obj) unless $TESTING;
+           print _prettyDump($obj);
         }
         return;
     }
@@ -223,7 +222,7 @@ sub run {
             }
             INFO $msg;
         } else {
-           print _prettyDump($obj) unless $TESTING;
+           print _prettyDump($obj);
         }
     }
     return;
@@ -239,15 +238,18 @@ sub _prettyDump {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::Client::Command - Command line type processing for clients.
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
@@ -281,10 +283,6 @@ is a filename (i.e. is it a YAML file that should be parsed and send
 as a hashref, or a filename that should be PUT?  Should STDIN be
 used?).  These need to be formalized and documented.
 
-=head1 NOTES
-
-This is a beta release, the API is subject to change without notice.
-
 =head1 METHODS
 
 =head2 C<run>
@@ -293,11 +291,11 @@ This is a beta release, the API is subject to change without notice.
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -309,4 +307,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
