@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: simple meta object for constructing clients
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 our %Routes; # hash from class name to array ref of routes.
 our %RouteAttributes; # hash from class name to hash ref of attributes.
@@ -78,19 +78,19 @@ sub objects {
 
 1;
 
-
-
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::Client::Meta - simple meta object for constructing clients
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 METHODS
 
@@ -99,15 +99,22 @@ version 1.00
 Add or replace documentation about a route.
 
 Parameters :
-    - the name of the client class
-    - the name of the route
-    - documentation about the route's arguments
+
+=over 4
+
+=item the name of the client class
+
+=item the name of the route
+
+=item documentation about the route's arguments
+
+=back
 
 =head2 get_route_doc
 
-Get documentation for a route.
+ $meta->get_route_doc($class,$route_name);
 
-    $meta->get_route_doc($class,$route_name);
+Get documentation for a route.
 
 =head2 add_route_attribute
 
@@ -115,16 +122,23 @@ Add an attribute for a route.
 
 Parameters :
 
-    - the name of the attribute
-    - the value of the attribute.
+=over 4
+
+=item the name of the attribute
+
+=item the value of the attribute.
+
+=back
 
 Recognized attributes :
 
-    - dont_read_files : if set, no attempt will be made to treat
-        arguments as yaml files.
-    - auto_failover : if set, when a connection fails and does not
-        return a status code, each url in the list of configured
-        failover_url's will be tried in turn.
+=over 4
+
+=item dont_read_files : if set, no attempt will be made to treat arguments as yaml files.
+
+=item auto_failover : if set, when a connection fails and does not return a status code, each url in the list of configured failover_url's will be tried in turn.
+
+=back
 
 =head2 get_route_attribute
 
@@ -132,12 +146,19 @@ Like the above but retrieve an attribute.
 
 =head2 add_object
 
-Add an object>
+Add an object.
 
 Parameters :
-    - the name of the client class
-    - the name of the object
-    - documentation about the object.
+
+=over 4
+
+=item the name of the client class
+
+=item the name of the object
+
+=item documentation about the object.
+
+=back
 
 =head2 routes, objects
 
@@ -153,11 +174,11 @@ L<Clustericious::Client>, L<Clustericious>
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -169,4 +190,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
