@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: default object returned from client methods
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 sub new
@@ -91,17 +91,19 @@ sub AUTOLOAD
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::Client::Object - default object returned from client methods
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
@@ -162,7 +164,7 @@ object methods to further interact with the REST server.
 
 =head1 METHODS
 
-=head2 C<new>
+=head2 new
 
  my $obj = Clustericious::Client::Object->new({ some => 'stuff'});
 
@@ -188,7 +190,7 @@ You can also include an optional 'client' parameter:
 that can be retrieved with $obj->_client().  This is useful for
 derived objects methods which need to access the Clustericious server.
 
-=head2 C<_client>
+=head2 _client
 
 my $obj->_client->do_something();
 
@@ -199,25 +201,37 @@ methods that need to interact with the server.
 
 These are also interesting:
 
- Data::AsObject
- Data::Autowrap
- Hash::AsObject
- Class::Builtin::Hash
- Hash::AutoHash
- Hash::Inflator
- Data::OpenStruct::Deep
- Object::AutoAccessor
+=over 4
 
- Mojo::Base
- Clustericious::Config
+=item L<Data::AsObject>
+
+=item L<Data::Autowrap>
+
+=item L<Hash::AsObject>
+
+=item L<Class::Builtin::Hash>
+
+=item L<Hash::AutoHash>
+
+=item L<Hash::Inflator>
+
+=item L<Data::OpenStruct::Deep>
+
+=item L<Object::AutoAccessor>
+
+=item L<Mojo::Base>
+
+=item L<Clustericious::Config>
+
+=back
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -229,7 +243,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
