@@ -5,7 +5,7 @@ use warnings;
 use base 'Clustericious::Client::Object';
 
 # ABSTRACT: object parameters
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 sub new
@@ -19,15 +19,18 @@ sub new
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::Client::Object::Params - object parameters
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
@@ -49,17 +52,17 @@ transforms it into a single flattened hash of name => value.
 
 =head1 METHODS
 
-=head2 C<new>
+=head2 new
 
  my $obj = Clustericious::Client::Object::Params->new($data);
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -71,4 +74,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
