@@ -5,26 +5,24 @@ use warnings;
 use Mojo::Base 'Mojolicious::Command';
 
 # ABSTRACT: Command base class
-our $VERSION = '1.00'; # VERSION
-
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::Command - Command base class
 
 =head1 VERSION
 
-version 1.00
-
-=head1 SYNOPSIS
-
- use Mojo::Base 'Mojolicious::Command';
+version 1.10_01
 
 =head1 DESCRIPTION
 
@@ -40,19 +38,23 @@ This is a (not exhaustive) list of common Clustericious commands:
 
 =item *
 
-L<hypnotoad|Clustericious::Command::hypnotoad>
+L<apache|Clustericious::Command::apache>
 
 =item *
 
-L<start|Clustericious::Command::start>
+L<configdebug|Clustericious::Command::configdebug>
 
 =item *
 
-L<stop|Clustericious::Command::stop>
+L<configpath|Clustericious::Command::configpath>
 
 =item *
 
-L<status|Clustericious::Command::status>
+L<configtest|Clustericious::Command::configtest>
+
+=item *
+
+L<configure|Clustericious::Command::configure>
 
 =item *
 
@@ -64,14 +66,30 @@ L<generate client|Clustericious::Command::generate::client>
 
 =item *
 
-L<generate mbd_app|Clustericious::Command::generate::mbd_app>
+L<hypnotoad|Clustericious::Command::hypnotoad>
+
+=item *
+
+L<lighttpd|Clustericious::Command::lighttpd>
+
+=item *
+
+L<plackup|Clustericious::Command::plackup>
+
+=item *
+
+L<start|Clustericious::Command::start>
+
+=item *
+
+L<status|Clustericious::Command::status>
+
+=item *
+
+L<stop|Clustericious::Command::stop>
 
 =back
 
-=head1 SUPER CLASS
-
-L<Mojolicious::Command>
-
 =head1 SEE ALSO
 
 L<Clustericious>
@@ -79,11 +97,11 @@ L<Mojolicious::Command>
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -95,4 +113,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
