@@ -6,43 +6,40 @@ use 5.010;
 use Mojo::Base 'Clustericious::Command';
 
 # ABSTRACT: Test a Clustericious application's configuration
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 has description => <<EOT;
-load configuration and test for errors
+Load configuration and test for errors
 EOT
 
 has usage => <<EOT;
 usage $0: configtest
-load configuration and test for errors
+Load configuration and test for errors
 EOT
 
 sub run
 {
-  my $self = shift;
-  my @args = @_ ? @_ : @ARGV;
-  
-  my $app = $self->app;
-  
-  exit 2 unless $app->sanity_check;
-  
+  my($self, @args) = @_;
+  exit 2 unless $self->app->sanity_check;
   say 'config okay';
 }
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::Command::configtest - Test a Clustericious application's configuration
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
@@ -76,21 +73,17 @@ do a sanity check of the configuration:
 This command does a basic sanity check on the configuration for your Clustericious
 application, and calls the application's C<sanity_check>
 
-=head1 SUPER CLASS
-
-L<Clustericious::Command>
-
 =head1 SEE ALSO
 
 L<Clustericious>
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -102,4 +95,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
