@@ -4,10 +4,10 @@ use strict;
 use warnings;
 use 5.010;
 use Mojo::Base 'Clustericious::Command';
-use Path::Class qw/dir/;
+use Path::Class qw( dir );
 
 # ABSTRACT: Generate a default configuration.
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 has description => <<EOT;
@@ -20,28 +20,27 @@ EOT
 
 sub run
 {
-  my $self = shift;
-  my @args = @_ ? @_ : @ARGV;
+  my($self, @args) = @_;
 
   my $root = dir($ENV{CLUSTERICIOUS_CONF_DIR} || $ENV{HOME});
   my $conf = $self->app->generate_config(@args);
 
   for my $d (@{$conf->{dirs} || []}) {
-      my $dir = dir($root, @$d);
-      -d $dir and do { say "-> exists : $dir"; next; };
-      my @made = $dir->mkpath;
-      say "-> mkdir $_" for @made;
+    my $dir = dir($root, @$d);
+    -d $dir and do { say "-> exists : $dir"; next; };
+    my @made = $dir->mkpath;
+    say "-> mkdir $_" for @made;
   }
   
   my $config_root = dir($root)->subdir('etc');
   for my $filename (keys %{$conf->{files}}) {
-      my $file = $config_root->file($filename);
-      -e $file and do {
-          say "-> exists : $file";
-          next;
-      };
-      say "-> write $file";
-      $file->spew($conf->{files}{$filename});
+    my $file = $config_root->file($filename);
+    -e $file and do {
+      say "-> exists : $file";
+      next;
+    };
+    say "-> write $file";
+    $file->spew($conf->{files}{$filename});
   }
 
   1;
@@ -49,17 +48,19 @@ sub run
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::Command::configure - Generate a default configuration.
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
@@ -81,7 +82,7 @@ Your app:
         files => { 'YourApp.conf' => <<<CUT }
  ---
  required_key   : default_value
- something_else : <%= $ENV{HOME} %>
+ something_else : <%= home %>
  CUT
    };
  }
@@ -92,21 +93,17 @@ Your app:
 
 Create a default configuration for an app.
 
-=head1 SUPER CLASS
-
-L<Clustericious::Command>
-
 =head1 SEE ALSO
 
 L<Clustericious>
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -118,4 +115,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
