@@ -5,7 +5,7 @@ use warnings;
 use Mojo::Base 'Mojolicious::Command::generate';
 
 # ABSTRACT: Clustericious code generation commands.
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 has namespaces =>
@@ -16,19 +16,23 @@ has namespaces =>
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::Command::generate - Clustericious code generation commands.
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
- % clustericious generate mbd_app Myapp --schema schema.sql
+ % clustericious generate app MyApp
+ % clustericious generate client MyApp
 
 =head1 DESCRIPTION
 
@@ -36,21 +40,17 @@ This is the base class for all Clustericious code generation commands.
 It inherits from L<Mojolicious::Command::generate> instead of
 L<Clustericious::Command>.
 
-=head1 SUPER CLASS
-
-L<Mojolicious::Command::generate>
-
 =head1 SEE ALSO
 
 L<Clustericious>
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -62,4 +62,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
