@@ -7,21 +7,22 @@ use Hash::Merge qw/merge/;
 use Data::Dumper;
 use Carp qw( croak );
 use base qw( Exporter );
-use JSON::XS qw( encode_json );
+use JSON::MaybeXS qw( encode_json );
+use Clustericious::Config;
 
 # ABSTRACT: Helpers for clustericious config files.
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 our @mergeStack;
-our @EXPORT = qw( extends_config get_password home file dir hostname hostname_full json yaml );
+our @EXPORT = qw( extends_config get_password home file dir hostname hostname_full json yaml address public_address interface );
 
 
-sub extends_config {
-    my $filename = shift;
-    my @args = @_;
-    push @mergeStack, Clustericious::Config->new($filename, \@args);
-    return '';
+sub extends_config
+{
+  my($name, @args) = @_;
+  push @mergeStack, Clustericious::Config->new($name, \@args);
+  return '';
 }
 
 #
@@ -32,24 +33,25 @@ sub extends_config {
 # directives.
 #
 sub _do_merges {
-    my $class = shift;
-    my $conf_data = shift; # Last one; Has highest precedence.
+  my($class, $data) = @_;
 
-    return $conf_data unless @mergeStack;
+  return $data unless @mergeStack;
 
-    # Nested extends_config's form a tree which we traverse depth first.
-    Hash::Merge::set_behavior( 'RIGHT_PRECEDENT' );
-    my %so_far = %{ shift @mergeStack };
-    while (my $c = shift @mergeStack) {
-        my %h = %$c;
-        %so_far = %{ merge( \%so_far, \%h ) };
-    }
-    %$conf_data = %{ merge( \%so_far, $conf_data ) };
+  # Nested extends_config's form a tree which we traverse depth first.
+  Hash::Merge::set_behavior( 'RIGHT_PRECEDENT' );
+  my %so_far = %{ shift @mergeStack };
+  while (my $c = shift @mergeStack)
+  {
+    my %h = %$c;
+    %so_far = %{ merge( \%so_far, \%h ) };
+  }
+  %$data = %{ merge( \%so_far, $data ) };
 }
 
 
-sub get_password {
-    return Clustericious::Config::Password->sentinel;
+sub get_password
+{
+  return Clustericious::Config::Callback::Password->new->to_yaml;
 }
 
 
@@ -114,18 +116,68 @@ sub yaml ($)
 }
 
 
+# TODO: for now the filtering of loop back only works on Linux
+# and any system where the loopback interface is lo
+
+sub address (;$)
+{
+  my($if) = @_;
+  
+  require Sys::HostAddr;
+  
+  my $filter = sub { !/^lo$/ };
+  
+  if(defined $if)
+  {
+    if(ref $if eq 'Regexp')
+    {
+      $filter = sub { $_ =~ $if };
+    }
+    elsif(ref $if eq 'ARRAY')
+    {
+      my %if = map { $_ => 1 } @$if;
+      $filter = sub { $if{$_} }
+    }
+    else
+    {
+      $filter = sub { $_ eq $if };
+    }
+  }
+
+  my @if = grep { $filter->() } @{ Sys::HostAddr->new(ipv=>4)->interfaces };
+  map { @{ $_->addresses } } map { Sys::HostAddr->new(ipv => 4, interface => $_) } @if;
+}
+
+
+sub public_address ()
+{
+  require Sys::HostAddr;
+  Sys::HostAddr->new(ipv=>4)->public;
+}
+
+
+sub interface ()
+{
+  require Sys::HostAddr;
+  grep !/^lo$/, @{ Sys::HostAddr->new(ipv=>4)->interfaces };
+}
+
+
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::Config::Helpers - Helpers for clustericious config files.
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
@@ -178,17 +230,39 @@ Encode the given hash or list reference.
 
 Encode the given hash or list reference.
 
+=head2 address( [ $interface ] )
+
+Returns a list of IP addresses.  Requires L<Sys::HostAddr> to be installed.
+C<$interfaces>, if specified may be either a string or regular expression.
+For example you can do C<address qr{^en[0-9]+$}> on Linux to get only ethernet
+interfaces.
+
+By default does not return loop back interfaces.
+
+Only returns IPv4 addresses.
+
+=head2 public_address
+
+Returns the public IPv4 address.  May not be an address on your host, if you
+are behind a firewall.  Requires L<Sys::HostAddr> to be installed.
+
+=head2 interface
+
+Returns a list of network interfaces.  Requires L<Sys::HostAddr> to be installed.
+
+By default does not return loop back interfaces.
+
 =head1 SEE ALSO
 
 L<Clustericious::Config>, L<Clustericious>
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -200,4 +274,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
