@@ -3,9 +3,10 @@ package Clustericious::Config::Plugin;
 use strict;
 use warnings;
 use Clustericious::Config::Helpers;
+use Carp ();
 
 # ABSTRACT: Deprecated module
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 # Hack to keep old versions of Test::Clustericious::Cluster working
@@ -16,18 +17,29 @@ sub Clustericious::Config::Helpers::cluster
   goto &Clustericious::Config::Plugin::cluster;
 }
 
+Carp::carp "Clustericious::Config::Plugin is deprecated and will be removed on or after January 31 2016";
+
+if(scalar caller eq 'Test::Clustericious::Cluster')
+{
+  Carp::carp "Upgrade your version of Test::Clustericious::Cluster, otherwise it will stop working when Clustericious::Config::Plugin is removed";
+}
+
+
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::Config::Plugin - Deprecated module
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 DESCRIPTION
 
@@ -36,11 +48,11 @@ L<Clustericious::Config::Helper>.
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -52,4 +64,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
