@@ -6,27 +6,31 @@ use Mojo::Base 'Clustericious::App';
 use Clustericious::RouteBuilder qw/Clustericious::HelloWorld/;
 
 # ABSTRACT: Clustericious hello world application
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
-BEGIN {
-    $ENV{LOG_LEVEL} = 'FATAL';
-}
+get '/' => sub { shift->render_text('Hello, world') } => 'index';
 
-any '/*foo' => {foo => '', text => 'Clustericious is working!'};
+get '/modules' => sub {
+  my %copy = %INC;
+  shift->stash->{autodata} = \%copy;
+} => 'modules';
 
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::HelloWorld - Clustericious hello world application
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
@@ -46,11 +50,11 @@ L<Clustericious>, L<Mojo::HelloWorld>
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -62,4 +66,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
