@@ -6,10 +6,10 @@ use List::Util qw( first );
 use Log::Log4perl qw( :easy );
 use MojoX::Log::Log4perl;
 use File::ReadBackwards;
-use File::HomeDir;
+use Clustericious;
 
 # ABSTRACT: A Log::Log4perl wrapper for use with Clustericious.
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 sub import {
@@ -19,8 +19,8 @@ sub import {
     if (my $app_name = $args{-init_logging}) {
         init_logging($app_name);
     }
-    no strict 'refs';
-    *{"${dest}::$_"} = *{"${class}::$_"} for qw/TRACE INFO DEBUG ERROR WARN FATAL LOGDIE get_logger/;
+    @_ = ($class, ':easy');
+    goto \&Log::Log4perl::import;
 }
 
 
@@ -34,8 +34,7 @@ sub init_logging {
     $Log::Log4perl::Logger::INITIALIZED = 0 if $initPid && $initPid != $$;
     $initPid = $$;
 
-    my $home = File::HomeDir->my_home;
-    my @Confdirs = ($home, "$home/etc", "/util/etc", "/etc" );
+    my @Confdirs = Clustericious->_config_path;
 
     # Logging
     $ENV{LOG_LEVEL} ||= 'WARN';
@@ -102,26 +101,29 @@ sub tail {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::Log - A Log::Log4perl wrapper for use with Clustericious.
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
  use Clustericious::Log -init_logging => "appname";
-
+ 
  use Clustericious::Log;
  INFO "Hi there!";
 
 =head1 DESCRIPTION
 
-This is a simple wrapper around Log::Log4perl for use with
+This is a simple wrapper around L<Log::Log4perl> for use with
 Clustericious.  It handles initialization and exporting of
 convenient logging functions, and a default set of logging
 patterns.  It also makes the name of the application available
@@ -129,7 +131,7 @@ for logging patterns (see the example).
 
 =head1 EXAMPLE
 
-Here is a sample ~/etc/log4perl.conf :
+Here is a sample C<~/etc/log4perl.conf> :
 
  log4perl.rootLogger=TRACE, LOGFILE
  log4perl.appender.LOGFILE=Log::Log4perl::Appender::File
@@ -145,8 +147,8 @@ Here is a sample ~/etc/log4perl.conf :
 
 =item init_logging
 
-Start logging.  Looks for log4perl.conf or $app.log4perl.conf
-in ~/etc, /util/etc and /etc.
+Start logging.  Looks for C<log4perl.conf> or C<$app.log4perl.conf>
+in C<~/etc> and C</etc>.
 
 =item tail
 
@@ -164,21 +166,17 @@ The following variables affect logging :
  LOG_FILE
  MOJO_APP
 
-=head1 NOTES
-
-This is a beta release, the API may change without notice.
-
 =head1 SEE ALSO
 
 L<Log::Log4perl>, L<Clustericious>
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -190,4 +188,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
