@@ -4,18 +4,18 @@ use strict;
 use warnings;
 use base 'Mojolicious::Plugin';
 use Mojo::ByteStream 'b';
-use JSON::XS;
+use JSON::MaybeXS;
 use YAML::XS qw/Dump Load/;
 use Clustericious::Log;
 
 # ABSTRACT: Handle data types automatically
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 my $default_decode = 'application/x-www-form-urlencoded';
 my $default_encode = 'application/json';
 
-my $json_encoder = JSON::XS->new->allow_nonref->allow_blessed->convert_blessed;
+my $json_encoder = JSON::MaybeXS->new->allow_nonref->allow_blessed->convert_blessed;
 
 my %types =
 (
@@ -124,15 +124,18 @@ sub _autodata_parse
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::Plugin::AutodataHandler - Handle data types automatically
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
@@ -171,11 +174,11 @@ too).
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -187,4 +190,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
