@@ -3,10 +3,11 @@ package Clustericious::RouteBuilder;
 use strict;
 use warnings;
 use 5.010;
+use Clustericious::App;
 use Log::Log4perl qw( :easy );
 
 # ABSTRACT: Route builder for Clustericious applications
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 our %Routes;
@@ -103,8 +104,7 @@ sub import {
     *{"${caller}::authorize"}    = sub { $route_sub->('authorize',@_) };
 }
 
-sub _add_routes {
-    my $class = shift;
+Clustericious::App->_add_route_builder(sub {
     my $app = shift;
     my $auth_plugin = shift;
 
@@ -173,21 +173,23 @@ sub _add_routes {
          # WebSocket
          $route->websocket if $websocket;
      }
-}
+});
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::RouteBuilder - Route builder for Clustericious applications
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
@@ -209,11 +211,7 @@ directly under your application's namespace (for example above MyApp's
 route module is MyApp::Routes).  The interface is reminiscent of 
 L<Mojolicious::Lite>, because it was forked from there some time ago.
 
-=head1 SUPER CLASS
-
-none
-
-=head1 METHODS
+=head1 FUNCTIONS
 
 =head2 any
 
@@ -257,11 +255,11 @@ L<Clustericious>, L<Mojolicious::Lite>
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -273,4 +271,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
