@@ -2,10 +2,9 @@ package Clustericious::RouteBuilder::Proxy;
 
 use strict;
 use warnings;
-use Clustericious::Log;
 
 # ABSTRACT: build proxy routes easily
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 use Sub::Exporter -setup => {
@@ -84,7 +83,7 @@ sub _build_proxy_service {
     my $service2sub;
     for my $service (keys %$name2url) {
         my $dest = $name2url->{$service} or next;
-        TRACE "Building proxy for $service to $dest";
+        #TRACE "Building proxy for $service to $dest";
         my $sub = $class->_build_proxy( "dummy", { to => $dest, strip_prefix => "/$service" } );
         $service2sub->{$service} = $sub;
     }
@@ -108,15 +107,18 @@ sub _sanitize_url {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::RouteBuilder::Proxy - build proxy routes easily
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
@@ -158,11 +160,11 @@ L<Clustericious>
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -174,4 +176,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
