@@ -3,11 +3,9 @@ package Clustericious::RouteBuilder::Search;
 use strict;
 use warnings;
 use Clustericious::Log;
-use List::MoreUtils qw/uniq/;
-use Data::Dumper;
 
 # ABSTRACT: build routes for searching for objects
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 use Sub::Exporter -setup => {
@@ -51,7 +49,7 @@ sub _build_search {
         }
 
 
-        TRACE "searching for $items : ".Dumper($p);
+        #TRACE "searching for $items : ".Dumper($p);
 
         # maybe restrict, by first calling $manager->normalize_get_objects_args(%$p)
 
@@ -83,15 +81,18 @@ sub _build_search {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::RouteBuilder::Search - build routes for searching for objects
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
@@ -138,11 +139,11 @@ L<Clustericious>
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -154,4 +155,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
