@@ -4,22 +4,22 @@ use strict;
 use warnings;
 
 # ABSTRACT: default templates for clustericious
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 1;
 
-
-
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Clustericious::Templates - default templates for clustericious
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 DESCRIPTION
 
@@ -32,11 +32,11 @@ L<Clustericious>
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -49,7 +49,6 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __DATA__
 
 @@ not_found.html.ep
