@@ -2,19 +2,19 @@ package Test::Clustericious;
 
 use strict;
 use warnings;
-
-# ABSTRACT: Test Clustericious apps
-our $VERSION = '1.00'; # VERSION
-
-
 use base 'Test::Mojo';
-
-use JSON::XS;
+use JSON::MaybeXS qw( encode_json decode_json );
 use YAML::XS;
 use Carp;
 use List::Util qw(first);
 use Clustericious::Config;
 
+Carp::carp "Test::Clustericious is deprecated and will be removed on or after January 31 2016";
+
+# ABSTRACT: Test Clustericious applications
+our $VERSION = '1.10_01'; # TRIAL VERSION
+
+
 require Test::More;
 
 
@@ -201,17 +201,19 @@ sub truncate_ok
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Test::Clustericious - Test Clustericious apps
+Test::Clustericious - Test Clustericious applications
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
@@ -237,14 +239,14 @@ L<Test::Mojo>, and add the following new attributes and methods.
 
 =head1 ATTRIBUTES
 
-=head2 C<server>
+=head2 server
 
  my $t = Test::Clustericious->new(server => 'MyServer');
 
 Looks up the URL for the server in the config file for the
 specified server.
 
-=head2 C<server_url>
+=head2 server_url
 
  my $t = Test::Clustericious->new(server_url => 'http://foo/');
 
@@ -252,13 +254,13 @@ Explicitly define a server url to test against.
 
 =head1 METHODS
 
-=head2 C<new>
+=head2 new
 
  my $t = Test::Clustericious(app => 'SomeMojoApp');
  my $t = Test::Clustericious(server => 'myapp');
  my $t = Test::Clustericious(server_url => 'http://foo'); 
 
-=head2 C<testdata>
+=head2 testdata
 
  my $object = $t->testdata('filename');
 
@@ -266,7 +268,7 @@ Looks for filename, filename.json, filename.yaml in 't', 'data' or
 't/data' directories.  Parses with json or yaml if appropriate, then
 returns the object.
 
-=head2 C<decoded_body>
+=head2 decoded_body
 
  $obj = $t->decoded_body;
 
@@ -276,7 +278,7 @@ Content-Type is application/json.
 Returns undef if the parse fails or the last request wasn't status
 2xx.
 
-=head2 C<create_ok>
+=head2 create_ok
 
  $obj = $t->create_ok('/url', { some => 'object' });
  $obj = $t->create_ok('/url', 'filename');
@@ -293,11 +295,11 @@ no returned object.
 
 This counts as 2 TAP tests.
 
-=head2 C<update_ok>
+=head2 update_ok
 
  update_ok is really just an alias for create_ok
 
-=head2 C<retrieve_ok>
+=head2 retrieve_ok
 
  $obj = $t->retrieve_ok('/url');
 
@@ -306,7 +308,7 @@ decoded body.
 
 This counts as 2 TAP tests.
 
-=head2 C<remove_ok>
+=head2 remove_ok
 
  $t->remove_ok($url);
 
@@ -315,7 +317,7 @@ Makes a DELETE request on the url, checks for status 200 and content of
 
 This counts as 6 TAP tests.
 
-=head2 C<notfound_ok>
+=head2 notfound_ok
 
  $t->notfound_ok($url[, $object]);
 
@@ -325,7 +327,7 @@ the encoded object and checks for a 404 response code and "not found" or
 
 This counts as 3 TAP tests.
 
-=head2 C<truncate_ok>
+=head2 truncate_ok
 
  $t->truncate_ok($url);
 
@@ -338,11 +340,11 @@ L<Clustericious>
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -354,7 +356,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
