@@ -3,21 +3,13 @@ package Test::Clustericious::Config;
 use strict;
 use warnings;
 use 5.010001;
-
-BEGIN {
-  unless($INC{'File/HomeDir/Test.pm'})
-  {
-    eval q{ use File::HomeDir::Test };
-    die $@ if $@;
-  }
-}
-
+use if !$INC{'File/HomeDir/Test.pm'}, 'File::HomeDir::Test';
 use File::HomeDir;
 use YAML::XS qw( DumpFile );
 use File::Path qw( mkpath );
 use Clustericious::Config;
 use Mojo::Loader;
-
+use Clustericious;
 use base qw( Test::Builder::Module Exporter );
 
 our @EXPORT = qw( create_config_ok create_directory_ok home_directory_ok create_config_helper_ok );
@@ -32,13 +24,13 @@ sub _init
   mkdir $config_dir;
 
   $ENV{CLUSTERICIOUS_CONF_DIR} = $config_dir;
-  Clustericious::Config->_testing(1);
+  Clustericious->_testing(1);
 }
 
 BEGIN { _init() }
 
 # ABSTRACT: Test Clustericious::Config
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.10_01'; # TRIAL VERSION
 
 
 sub create_config_ok ($;$$)
@@ -87,7 +79,7 @@ sub create_config_ok ($;$$)
   $test_name //= "create config for $config_name at $config_filename";
   
   # remove any cached copy if necessary
-  Clustericious::Config->_uncache($config_name);
+  Clustericious->_config_uncache($config_name);
 
   $tb->ok($ok, $test_name);
   return $config_filename;
@@ -145,17 +137,19 @@ sub create_config_helper_ok ($$;$)
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Clustericious::Config - Test Clustericious::Config
 
 =head1 VERSION
 
-version 1.00
+version 1.10_01
 
 =head1 SYNOPSIS
 
@@ -208,7 +202,7 @@ from any configurations you may have in your C<~/etc>.  Keep
 in mind that this means that C<$HOME> and friends will be in
 a temporary directory and removed after the test runs.  It also
 means that the caveats for L<File::HomeDir::Test> apply when
-using this module as well (ie. this should be the first module
+using this module as well (specifically this should be the first module
 that you use in your test after C<use strict> and C<use warnings>).
 
 =head1 FUNCTIONS
@@ -301,11 +295,11 @@ To see the full tests see t/073_tempdir.t in the L<Yars> distribution.
 
 =head1 AUTHOR
 
-original author: Brian Duggan
+Original author: Brian Duggan
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Curt Tilmes
 
@@ -317,4 +311,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
